<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Mozgaration Theme Custom Controls
 * @return $type
 */
function mozgaration_custom_controls( $wp_customize ){


		/**
		 * Custom Media Control Class 
		 */
		class MOZGARATION_Customize_Media_Control extends WP_Customize_Control {

			public $type = 'mozgaration_media';
			public $statuses;

			public function enqueue() {
				wp_enqueue_media(); 
			}

		 	/**
			 * Constructor.
			 *
			 * If $args['settings'] is not defined, use the $id as the setting ID.
			 *
			 * @since   01/16/2017
			 * @uses    WP_Customize_Control::__construct()
			 * @param   WP_Customize_Manager $manager
			 * @param   string $id
			 * @param   array $args
			 * @return  void
			 */
			public function __construct( $manager, $id, $args = array() ) {

				$this->statuses = array( '' => __( 'Default', 'mozgaration' ) );
				parent::__construct( $manager, $id, $args );
			}

	
			/**
			 * Constructor.
			 *
			 * @since 3.4.0
			 * @uses WP_Customize_Image_Control::__construct()
			 *
			 * @param WP_Customize_Manager $manager
			 */
			public function render_content() {

				$field_value = esc_html( $this->value() );
				$id = $this->id;
				?>

				<label>

					<?php if ( ! empty( $this->label ) ) : ?>
						<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php endif;
					if ( ! empty( $this->description ) ) : ?>
						<span class="description customize-control-description"><?php echo $this->description; ?></span>
					<?php endif; ?>

					
					<div class="form_element upload">
						<input id="<?php echo $id; ?>" autocomplete="off" type="text" <?php $this->link(); ?> class="upload_field">  
						<button data-inputid="<?php echo $id ?>" class="button icon-upload mozgarationtheme_upload_button" type="button"><?php echo __('Upload','mozgaration'); ?></button>
					</div>

					<?php
					//the file extention
					$ext = pathinfo($field_value, PATHINFO_EXTENSION);

					//is the file an image?
					if( $ext == "jpg" || $ext == "jpeg" || $ext == "png" || $ext == "gif" ){
						$ext_image = true;
					}else{
						$ext_image = false;
					}												

					echo ($field_value && $ext_image ) ? '<div data-holderid="'.$id.'" class="uploaded_file visible">' : '<div data-holderid="'.$id.'" class="uploaded_file ">'; 

						if($field_value){
							echo '<img class="loadit" src="'.$field_value.'"  data-image="'.$id.'" >';
						}else{ 
							echo '<img class="loadit" src="'.MOZGARATION_THEMEADMINURI.'/images/blank.png"  data-image="'.$id.'">';	 			
						}  

					echo '<span class="icon-cancel delete_single" title="'.__("remove image","mozgaration").'" data-inputid="'.$id.'"></span>';
					echo '</div>';
					?>

				</label>

				<?php				
			}

		}

		/**
		 * Custom Color Control with RGBA Supporrt
		 */
		class MOZGARATION_Color_Control extends WP_Customize_Control {

			public $type = 'mozgaration_color';
			public $default = '';

			/**
			 * Constructor.
			 * @param WP_Customize_Manager $manager
			 */
			public function render_content() { ?>
				<label>

					<?php if ( ! empty( $this->label ) ) : ?>
						<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php endif;
					if ( ! empty( $this->description ) ) : ?>
						<span class="description customize-control-description"><?php echo $this->description; ?></span>
					<?php endif; ?>

					<div class="customize-control-content">
						<div class="wp-picker-container">
							<a class="mozgaration-color-control-result wp-color-result" tabindex="0" style="background-color: <?php echo $this->value(); ?>" title="<?php echo __("Select Color","mozgaration"); ?>" data-current="<?php echo __("Current Color","mozgaration"); ?>"></a>
							
							<span class="wp-picker-input-wrap">
								<input type="text" value="<?php echo $this->value(); ?>" <?php $this->link(); ?> class="wp-color-picker" data-default-color="<?php echo $this->default; ?>" style="display:none;">
								<input class="button button-small wp-picker-default mozgaration-color-control-default" type="button" value="Default" style="display:none;">
							</span>

							<div class="mozgaration-color-control" data-elemenet-id="<?php echo $this->id; ?>"></div>
						</div>
					</div>

				</label>

			<?php }

		}

		/**
		 * Custom Select Control with input_attrs and optgroup support & customizations for mozgaration_fonts
		 */
		class MOZGARATION_Select_Control extends WP_Customize_Control {

			public $type = 'mozgaration_select';
			public $default = '';


			/**
			 * Construct
			 */
			public function __construct( $manager, $id, $args ) { 

				parent::__construct( $manager, $id, $args );
 
				// prapare atts for google font subsets
				if( isset($this->input_attrs["class"]) && $this->input_attrs["class"] == "mozgaration_fonts" ){

					$data_subset_id = get_theme_mod( $this->input_attrs["data-subset-id"] );
					$data_variant_id = get_theme_mod( $this->input_attrs["data-variant-id"] );

					$this->input_attrs["data-selected-subsets"] = ! empty($data_subset_id) ? implode(",", $data_subset_id ) : "";
					$this->input_attrs["data-selected-variant"] = ! empty($data_subset_id) ? $data_variant_id : "";					

				}
				
			}


			/**
			 * Render content
			 */
			public function render_content() {  
				?>
					<label>
						<?php if ( ! empty( $this->label ) ) : ?>
							<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
						<?php endif;
						if ( ! empty( $this->description ) ) : ?>
							<span class="description customize-control-description"><?php echo $this->description; ?></span>
						<?php endif; ?>

						<select <?php $this->link(); ?> <?php $this->input_attrs(); ?>>
							<?php
							foreach ( $this->choices as $value => $label )

								switch ( $value ) {

									case strpos($value, "obt_start") > 0 :
										echo '<optgroup label="' . $label . '"">';	
										break;
								
									case strpos($value, "obt_end") > 0 :
										echo '</optgroup>';	
										break;

									case strpos( $value, "\"kind\":") > 0 :
										$this->create_font_option( $value, $label );
										break;

									default:
										echo '<option value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . $label . '</option>';
										break;
								}
								
							?>
						</select>
					</label>
				<?php
			}


			/**
			 * createa an option for font lists
			 */
			public function create_font_option( $value, $label ) {  

				$font_data = json_decode( $value );
				echo '<option value="' . $font_data->kind . '||'. $font_data->family .'" data-subsets="'. implode($font_data->subsets,',') .'" data-variants="'. implode($font_data->variants,',') .'" >' . $label . '</option>';	

			}


		}		

		/**
		 * Custom Content
		 */
		class MOZGARATION_Content_Control extends WP_Customize_Control {

			public $type = 'mozgaration_contents';
			public $default = '';

 
			/**
			 * Render content
			 */
			public function render_content() {  
				?>
					<label>
						<?php if ( ! empty( $this->label ) ) : ?>
							<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>	
						<?php endif; ?>

							<section class="mozgaration_contnet_control">
								<?php
								 if ( ! empty( $this->description ) ) : ?>
									<?php echo $this->description; ?>
								<?php endif;?> 
							</section>
							
					</label>
				<?php
			}

		}	

		/**
		 * Custom Checkbox
		 */
		class MOZGARATION_Checkbox_Control extends WP_Customize_Control {

			public $type = 'mozgaration_checkbox';
			public $default = '';

 
			/**
			 * Render content
			 */
			public function render_content() {  
				?>
					<label>
						<input type="checkbox" value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); checked( $this->value() ); $this->input_attrs(); ?> />
						<?php echo esc_html( $this->label ); ?>
						<?php if ( ! empty( $this->description ) ) : ?>
							<span class="description customize-control-description"><?php echo $this->description; ?></span>
						<?php endif; ?>
					</label>					

				<?php
			}

		}	



		/**
		 * Custom Seperator
		 */
		class MOZGARATION_Seperator_Control extends WP_Customize_Control {

			public $type = 'mozgaration_seperator';
			public $default = '';

 
			/**
			 * Render content
			 */
			public function render_content() {  
				?>
					<label>
						<hr class="mozgaration_seperator" />
						<?php if ( ! empty( $this->label ) ) : ?>
							<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
						<?php endif;
						if ( ! empty( $this->description ) ) : ?>
							<span class="description customize-control-description"><?php echo $this->description; ?></span>
						<?php endif; ?>
					</label>
				<?php
			}

		}	

		/**
		 * Custom SubSection Heading
		 */
		class MOZGARATION_SubSection_Heading extends WP_Customize_Control {

			public $type = 'mozgaration_subsection_heading';
			public $default = '';

 
			/**
			 * Render content
			 */
			public function render_content() {  
				?>
					<label>
				 
						<?php if ( ! empty( $this->label ) ) : ?> 
							<h3 class="mozgaration-customizer-subsection-title"><span class="dashicons-arrow-down-alt2"></span><?php echo esc_html( $this->label ); ?></h3>
						<?php endif;
						if ( ! empty( $this->description ) ) : ?>
							<span class="description customize-control-description"><?php echo $this->description; ?></span>
						<?php endif; ?>
					</label>
				<?php
			}

		}			
}
add_action( 'customize_register', 'mozgaration_custom_controls' );

