<?php
#-----------------------------------------
#	Mozgaration theme mozgaration_breadcrumb.php
#-----------------------------------------

add_action("mozgaration_breadcrumb_menu", "mozgaration_breadcrumb", 10, 1 );

/* MOZGARATION-Breadcrumb Function */ 
if( ! function_exists('mozgaration_breadcrumb') ){
	function mozgaration_breadcrumb( $args = array() ){
		global $mozgaration_taxonomy, $post, $mozgaration_delimiter, $mozgaration_item_position, $wp_query;

		//the breadcrumb text before the menu
		$breadcrumb_text = "";

		//default values
		$defaults =  array(
			'mozgaration_delimiter'   => ' <span class="icon-angle-right"></span> ',
			'wrap_before' => '',
			'wrap_after'  => '',
			'breadcrumb_text' => ''.mozgaration_wpml_t(MOZGARATION_THEMESLUG, 'Breadcrumb Menu Text', $breadcrumb_text ).'',
			'home'        => __( 'Home', 'mozgaration' ),
		);

		$args = wp_parse_args( $args, $defaults );

		//extract variables
		extract( $args );

		//define variables
		$mozgaration_is_bbpress = $breadcrumb = ""; 
	 
		/*  WooCommerce Breadcrumb */ 
		if ( function_exists( 'woocommerce_breadcrumb' ) ) {
			if( is_woocommerce() ){
				$defaults = array(
					'delimiter'  => $mozgaration_delimiter,
					'wrap_before'  => $wrap_before. '<ol vocab="http://schema.org/" typeof="BreadcrumbList">' . '<li property="itemListElement" typeof="ListItem"><a class="icon-home" property="item" typeof="WebPage" href="'. MOZGARATION_BLOGURL .'"><span property="name">'.$home.'</span></a><meta content="1" property="position"></li>' .$mozgaration_delimiter,
					'wrap_after' => '</ol>'.$wrap_after,
					'before'   => '<li property="itemListElement" typeof="ListItem">',
					'after'   => '</li>',
					'home'    => false,
				);
			
				ob_start();
				woocommerce_breadcrumb($defaults);
				$breadcrumb = ob_get_contents();
				ob_end_clean();
				return $breadcrumb; 
			}
		} 

		/*  YOAST Breadcrumb */ 
		if ( function_exists( 'yoast_breadcrumb' ) ) {
			$yoast_options = get_option( 'wpseo_internallinks' );
			if(isset($yoast_options['breadcrumbs-enable'])  && !empty($yoast_options['breadcrumbs-enable'])){
				yoast_breadcrumb($wrap_before ,$wrap_after);
				return false;
			}
		} 

		$breadcrumb .= $wrap_before;
		$breadcrumb .= ! empty( $breadcrumb_text ) ? $breadcrumb_text." " : "";

		/*
		  BBPRESS Breadcrumb
		  use BBpress Breadcrumb if for bbpress pages
		*/ 
		if ( function_exists( 'bbp_breadcrumb' ) ) {
			global $mozgaration_bb_breadcrumb, $mozgaration_wrap_before,$mozgaration_wrap_after,$mozgaration_breadcrumb_text;

			$mozgaration_wrap_before = $wrap_before;
			$mozgaration_wrap_after = $wrap_after;
			$mozgaration_breadcrumb_text = $breadcrumb_text;

			//check the current page is if it is part of bbpress
			if ( is_bbpress() ){  
				$breadcrumb .= $mozgaration_bb_breadcrumb;
				$mozgaration_is_bbpress = true; 
			}  
		} 

		//if its not a bbpress page run default breadcrumb
		if( ! $mozgaration_is_bbpress ){

				

				$breadcrumb .= '<ol vocab="http://schema.org/" typeof="BreadcrumbList">'."\n";


				//Home Page
				if( ! is_front_page() ){
					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "class" => "icon-home", "sublink" => false, "url"=> MOZGARATION_BLOGURL, "title"=> get_bloginfo('name'), "link_name" => $home ) );
				}

				//Pages
				if ( is_page() && ! is_front_page() && $post ){
					$breadcrumb .= mozgaration_page_parents( $post, "" ) . mozgaration_create_breadcrumb_item( array( "mozgaration_delimiter" => "", "title" => get_the_title( mozgaration_wpml_translated_page_id( $post->ID ) ) ) );
				}

				//Single posts
				elseif ( is_single() && !is_attachment() ){ 

				
					// Get post type
					$post_type = get_post_type();

					//regular single posts 
					if($post_type == 'post'){ 

						//get base page
			 			$breadcrumb .= mozgaration_get_base_page("blog");

						$this_category = get_the_category();  

						if( isset( $this_category[0] ) ){
							$breadcrumb .= mozgaration_get_category_parents( $this_category[0] );
						}

						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> $post->post_title, "mozgaration_delimiter" => "" ) );

					}

					//product single posts 
					elseif($post_type == 'products'){ 
			 
			 			//get base page
			 			$breadcrumb .= mozgaration_get_base_page("products");

						//categories of post
						$terms = wp_get_post_terms( $post->ID, "product_categories",  array( 'orderby' => 'parent', 'order' => 'DESC' ) );

						//select only 1st one and create breadcrumb link
						if( isset( $terms[0] ) ){

							$term_link = get_term_link( $terms[0]->slug, $terms[0]->taxonomy );
							$term_name = $terms[0]->name;

							//check term has parents
							if( $terms[0]->parent ){
								$breadcrumb .= mozgaration_get_term_parents( $terms[0]->term_id, $terms[0]->taxonomy );
							}

							//breadcrumb link of the term
							$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> esc_attr( sprintf( __( "View all products in %s", "mozgaration" ), $term_name ) ), "link_name"=> esc_attr( $term_name ), "url" =>  esc_url( $term_link ) ) );

						}
						
						//breadcrumb link of current post
						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> $post->post_title, "mozgaration_delimiter" => "" ) );

					}

					//portfolio single posts 
					elseif($post_type == 'portfolio'){ 
			 
			 			//get base page
			 			$breadcrumb .= mozgaration_get_base_page("portfolio");

						//categories of post
						$terms = wp_get_post_terms( $post->ID, "portfolio_categories",  array( 'orderby' => 'parent', 'order' => 'DESC' ) );

						//select only 1st one and create breadcrumb link
						if( isset( $terms[0] ) ){

							$term_link = get_term_link( $terms[0]->slug, $terms[0]->taxonomy );
							$term_name = $terms[0]->name;

							//check term has parents
							if( $terms[0]->parent ){
								$breadcrumb .= mozgaration_get_term_parents( $terms[0]->term_id, $terms[0]->taxonomy );
							}

							//breadcrumb link of the term
							$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> esc_attr( sprintf( __( "View all works in %s", "mozgaration" ), $term_name ) ), "link_name"=> esc_attr( $term_name ), "url" =>  esc_url( $term_link ) ) );

						}
						
						//breadcrumb link of current post
						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> $post->post_title, "mozgaration_delimiter" => "" ) );

					}		

					//staff single posts 
					elseif($post_type == 'staff'){ 
			 
			 			//get base page
			 			$breadcrumb .= mozgaration_get_base_page("staff"); 
			 			
						//breadcrumb link of current post
						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> $post->post_title, "mozgaration_delimiter" => "" ) );

					}		

					//other single custom posts
					else{ 						
						
						//breadcrumb link of current post
						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> $post->post_title, "mozgaration_delimiter" => "" ) );

					}	

				}

				//Taxonomies
				elseif ( is_tax() ){
			 
						//get base page for products
						if( get_query_var( 'taxonomy' ) == "product_categories" ){
						 	$breadcrumb .= mozgaration_get_base_page("products");
						}

						//get base page for portfolio
						if( get_query_var( 'taxonomy' ) == "portfolio_categories" ){
						 	$breadcrumb .= mozgaration_get_base_page("portfolio");
						}			

						$this_term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) ); 

						$breadcrumb .= mozgaration_get_term_parents( $this_term->term_id, $this_term->taxonomy );			 
						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> esc_attr( $this_term->name ), "mozgaration_delimiter"=>""  ) );

				}

				//categories
				elseif ( is_category() ){

			 			//get base page
			 			$breadcrumb .= mozgaration_get_base_page("blog");

						$this_category_obj = $wp_query->get_queried_object();
						$this_category = get_category( $this_category_obj->term_id ); 

						if( $this_category->parent ){
							$breadcrumb .= mozgaration_get_category_parents( $this_category->parent );
						}

						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> esc_attr( $this_category->name ), "mozgaration_delimiter"=>""  ) );
			 

				//404
				} elseif ( is_404() ) {

					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> __( 'Error 404', 'mozgaration' ),  "mozgaration_delimiter"=>""  ) );


				//search
				} elseif ( is_search() ) {

					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> sprintf( __( 'Search results for: %s', 'mozgaration' ), get_search_query() ),  "mozgaration_delimiter"=>""  ) );

				//tag
				} elseif ( is_tag() ) {

					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> sprintf( __( 'Posts tagged: %s', 'mozgaration' ), single_tag_title('', false) ),  "mozgaration_delimiter"=>""  ) );

				//author
				} elseif ( is_author() ) {

					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> sprintf( __( 'Author: %s', 'mozgaration' ), get_the_author() ),  "mozgaration_delimiter"=>""  ) );

				//attachment
				} elseif ( is_attachment() ) {


					$this_category = get_the_category();  

					if( $this_category ){
						$breadcrumb .= mozgaration_get_category_parents( $this_category );
					}

					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> $post->post_title, "mozgaration_delimiter" => "" ) );
 
				//archive
				}elseif ( is_archive() ) { 

					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> mozgaration_get_title(), "mozgaration_delimiter" => "" ) );

				//posts page
				}elseif ( is_home() ) { 

					$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> get_the_title( get_option( 'page_for_posts' ) ), "mozgaration_delimiter" => "" ) );
		
				}else {

					if( ! is_front_page() ){
						$breadcrumb .= mozgaration_create_breadcrumb_item( array( "title"=> wp_title('|',false), "link_name"=> wp_title('|',false), "mozgaration_delimiter"=>""  ) );
					}
				}
				

			//close
			$breadcrumb .= "</ol>"."\n"; 
		}

		$breadcrumb .= $wrap_after;

		$breadcrumb_menu = $breadcrumb;
	 
		//echo breadcrumb
		return $breadcrumb_menu;
	}
}

// page category parents function
if( ! function_exists('mozgaration_get_term_parents') ){
	function mozgaration_get_term_parents( $term_id, $mozgaration_taxonomy) {
	 		
	 		$item = "";
			$the_term = get_term_by( 'id', $term_id , $mozgaration_taxonomy );		 
			$get_ancestors = array_reverse( get_ancestors( $the_term->term_id, $mozgaration_taxonomy ) );
	 
			foreach ( $get_ancestors as $ancestor ) {
				$ancestor = get_term( $ancestor, $mozgaration_taxonomy );
				$link = get_term_link( $ancestor->slug, $mozgaration_taxonomy ) ;
				$name = esc_html( $ancestor->name ) ;
				$item .= mozgaration_create_breadcrumb_item( array( "title"=> esc_attr( $name ), "link_name"=> $name, "url" =>  esc_url( $link ) ) );
			} 

			return $item;
	}
}

// page category parents function
if( ! function_exists('mozgaration_get_category_parents') ){	
	function mozgaration_get_category_parents( $id, $visited = array() ) {
		$chain = '';
		$parent = get_term( $id, 'category' );

		if ( is_wp_error( $parent ) )
			return $parent; 
	 
		$name = $parent->name;

		if ( $parent->parent && ( $parent->parent != $parent->term_id ) && !in_array( $parent->parent, $visited ) ) {
			$visited[] = $parent->parent;
			$chain .= mozgaration_get_category_parents( $parent->parent, $visited );
		}

		$chain .= mozgaration_create_breadcrumb_item( array( "title"=> esc_attr( sprintf( __( "View all posts in %s", "mozgaration" ), $parent->name ) ), "link_name"=> esc_attr( $parent->name ), "url" =>  esc_url( get_category_link( $parent->term_id ) ) ) );

		return $chain;
	}
}

// page parents function
if( ! function_exists('mozgaration_create_breadcrumb_item') ){	

	function mozgaration_create_breadcrumb_item( $atts = array() ){
		global $mozgaration_delimiter, $mozgaration_item_position;

		//defaults
		extract(shortcode_atts(array(
			"sublink" => "true",
			"url"     => "",
			"title"   => "",
			"link_name"=> "",
			"mozgaration_delimiter" => $mozgaration_delimiter,
			"class" => ""
		), $atts));

		$link_name = ! empty( $link_name ) ? $link_name : $title;

		if ( empty( $link_name ) ){
			return;
		}

		if ( ! isset( $mozgaration_item_position ) || empty( $mozgaration_item_position ) ){
			$mozgaration_item_position = 1;
		}else{
			$mozgaration_item_position++;
		}

		$item = "";

		$item .=  '<li property="itemListElement" typeof="ListItem">'."\n";

		$item .= ! empty( $url ) ? '<a property="item" typeof="WebPage" class="'.$class.'" href="'.$url.'">' : "";

		$item .= ! empty( $url ) ? 
						'<span property="name">' . $link_name . '</span>' : 
						'
						<meta itemprop="name" content="'.get_the_title().'">
						<meta itemprop="url" content="'.get_permalink().'">
						<span property="name">' . $link_name . '</span>
						';

		$item .= '<meta property="position" content="'.$mozgaration_item_position.'">' ;

		$item .= ! empty( $url ) ? '</a>' : ""; 		

		$item .= $mozgaration_delimiter; 

		$item .= '</li>'."\n";

		return $item;
	}



}

// page parents function
if( ! function_exists('mozgaration_page_parents') ){	
	function mozgaration_page_parents( $post, $items ){
 

		//parent pages
		if ( $post->post_parent ){		

				//find parent page of this page
				$parent_page = get_page( $post->post_parent );

				//create breadcrum item for this page
				$items = mozgaration_create_breadcrumb_item( array( "url"=> get_permalink( mozgaration_wpml_translated_page_id( $parent_page->ID ) ), "title"=> get_the_title( mozgaration_wpml_translated_page_id( $parent_page->ID ) ) ) ) . $items;

				//find parent page of the parent page			
				return mozgaration_page_parents( $parent_page, $items );

		}else{
			return $items; 
		}
		
	}
}

//get base page
if( ! function_exists('mozgaration_get_base_page') ){	
	function mozgaration_get_base_page( $for = "" ){

		global $mozgaration_global_variables;

		$page = "";

		if( $for == "products" && $mozgaration_global_variables['mozgaration_productpage'] ){ 

			$page = mozgaration_create_breadcrumb_item( array( "url"=> get_permalink( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_productpage'] ) ), "title"=> get_the_title( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_productpage'] ) ) ) ) ;

		}elseif( $for == "portfolio" && $mozgaration_global_variables['mozgaration_portfoliopage'] ){ 
			
			$page = mozgaration_create_breadcrumb_item( array( "url"=> get_permalink( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_portfoliopage'] ) ), "title"=> get_the_title( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_portfoliopage'] ) ) ) ) ;

		}elseif( $for == "blog" && $mozgaration_global_variables['mozgaration_blogpage'] ){ 

			$page = mozgaration_create_breadcrumb_item( array( "url"=> get_permalink( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_blogpage'] ) ), "title"=> get_the_title( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_blogpage'] ) ) ) ) ;

		}elseif( $for == "staff" && $mozgaration_global_variables['mozgaration_staffpage']){ 

			$page = mozgaration_create_breadcrumb_item( array( "url"=> get_permalink( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_staffpage'] ) ), "title"=> get_the_title( mozgaration_wpml_translated_page_id( $mozgaration_global_variables['mozgaration_staffpage'] ) ) ) ) ;			

		}

		return $page;
	}
}
?>